@@ -15,9 +15,8 @@ __doc__="""System management components"""
 __version__='$Revision: 1.94 $'[11:-2]
 
 import sys,os,time,Globals, Acquisition, os, Undo
-import logging
-logger = logging.getLogger('ApplicationManager')
-
+from logging import getLogger
+from Globals import InitializeClass
 from Globals import DTMLFile
 from OFS.ObjectManager import ObjectManager
 from OFS.Folder import Folder
@@ -31,12 +30,13 @@ from Product import ProductFolder
 from version_txt import version_txt
 from cStringIO import StringIO
 from AccessControl import getSecurityManager
-from AccessControl.requestmethod import postonly
 from zExceptions import Redirect
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from cgi import escape
 import Lifetime
 
+LOG = getLogger('ApplicationManager')
+
 try: import thread
 except: get_ident=lambda: 0
 else: get_ident=thread.get_ident
@@ -72,8 +72,8 @@ class DatabaseManager(Fake, SimpleItem.Item, Acquisition.Implicit):
     manage_cacheParameters=Globals.DTMLFile('dtml/cacheParameters', globals())
     manage_cacheGC=Globals.DTMLFile('dtml/cacheGC', globals())
 
+InitializeClass(DatabaseManager)
 
-Globals.default__class_init__(DatabaseManager)
 
 class FakeConnection:
     # Supports the methods of Connection that CacheManager needs
@@ -136,7 +136,7 @@ class DatabaseChooser (SimpleItem.SimpleItem):
             res.append(m.__of__(self))
         return res
 
-Globals.InitializeClass(DatabaseChooser)
+InitializeClass(DatabaseChooser)
 
 
 class VersionManager(Fake, SimpleItem.Item, Acquisition.Implicit):
@@ -155,7 +155,7 @@ class VersionManager(Fake, SimpleItem.Item, Acquisition.Implicit):
         )
         )
 
-Globals.default__class_init__(VersionManager)
+InitializeClass(VersionManager)
 
 
 
@@ -267,7 +267,7 @@ class DebugManager(Fake, SimpleItem.Item, Acquisition.Implicit):
     def manage_getSysPath(self):
         return list(sys.path)
 
-Globals.default__class_init__(DebugManager)
+InitializeClass(DebugManager)
 
 
 
@@ -388,14 +388,13 @@ class ApplicationManager(Folder,CacheManager):
 
     if os.environ.has_key('ZMANAGED'):
         manage_restartable=1
-        @postonly
-        def manage_restart(self, URL1, REQUEST=None):
+        def manage_restart(self, URL1):
             """Shut down the application"""
             try:
                 user = '"%s"' % getSecurityManager().getUser().getUserName()
             except:
                 user = 'unknown user'
-            logger.info("Restart requested by %s" % user)
+            LOG.info("Restart requested by %s" % user)
             #for db in Globals.opened: db.close()
             Lifetime.shutdown(1)
             return """<html>
@@ -404,14 +403,13 @@ class ApplicationManager(Folder,CacheManager):
             <body>Zope is restarting</body></html>
             """ % escape(URL1, 1)
 
-    @postonly
-    def manage_shutdown(self, REQUEST=None):
+    def manage_shutdown(self):
         """Shut down the application"""
         try:
             user = '"%s"' % getSecurityManager().getUser().getUserName()
         except:
             user = 'unknown user'
-        logger.info("Shutdown requested by %s" % user)
+        LOG.info("Shutdown requested by %s" % user)
         #for db in Globals.opened: db.close()
         Lifetime.shutdown(0)
         return """<html>
@@ -420,7 +418,6 @@ class ApplicationManager(Folder,CacheManager):
         <body>Zope is shutting down</body></html>
         """
 
-    @postonly
     def manage_pack(self, days=0, REQUEST=None):
         """Pack the database"""
 
@@ -475,7 +472,6 @@ class ApplicationManager(Folder,CacheManager):
             r.append({'id': v})
         return r
 
-    @postonly
     def manage_saveVersions(self, versions, REQUEST=None):
         "Commit some versions"
         db=self._p_jar.db()
@@ -484,7 +480,6 @@ class ApplicationManager(Folder,CacheManager):
         if REQUEST is not None:
             REQUEST['RESPONSE'].redirect(REQUEST['URL1']+'/manage_main')
 
-    @postonly
     def manage_discardVersions(self, versions, REQUEST=None):
         "Discard some versions"
         db=self._p_jar.db()
