@@ -12,17 +12,19 @@
 ##############################################################################
 """Application support
 
-$Id: Application.py 69766 2006-08-24 15:13:43Z shh $
+$Id: Application.py 69793 2006-08-27 13:44:44Z shh $
 """
 
 import os, sys, traceback
+from logging import getLogger
 from cgi import escape
 from StringIO import StringIO
 from warnings import warn
 
 import Globals, Products, App.Product, App.ProductRegistry
-import logging
 import transaction
+from Globals import InitializeClass
+from AccessControl import ClassSecurityInfo
 from AccessControl.User import UserFolder
 from Acquisition import aq_base
 from App.ApplicationManager import ApplicationManager
@@ -33,6 +35,7 @@ from DateTime import DateTime
 from HelpSys.HelpSys import HelpSys
 from webdav.NullResource import NullResource
 from zExceptions import Redirect as RedirectException, Forbidden
+
 from zope.interface import implements
 
 import Folder
@@ -42,7 +45,7 @@ from FindSupport import FindSupport
 from interfaces import IApplication
 from misc_ import Misc_
 
-logger = logging.getLogger('Zope')
+LOG = getLogger('Application')
 
 class Application(Globals.ApplicationDefaultPermissions,
                   ZDOM.Root, Folder.Folder,
@@ -52,8 +55,9 @@ class Application(Globals.ApplicationDefaultPermissions,
 
     implements(IApplication)
 
+    security = ClassSecurityInfo()
+
     title ='Zope'
-    #__roles__=['Manager', 'Anonymous']
     __defined_roles__=('Manager','Anonymous','Owner')
     web__form__method='GET'
     isTopLevelPrincipiaApplicationObject=1
@@ -104,7 +108,7 @@ class Application(Globals.ApplicationDefaultPermissions,
         return self.title
 
     def __class_init__(self):
-        Globals.default__class_init__(self)
+        InitializeClass(self)
 
     def PrincipiaRedirect(self, destination, URL1):
         """Utility function to allow user-controlled redirects"""
@@ -136,7 +140,7 @@ class Application(Globals.ApplicationDefaultPermissions,
 
     ZopeTime = PrincipiaTime
 
-    ZopeAttributionButton__roles__=None
+    security.declarePublic('ZopeAttributionButton')
     def ZopeAttributionButton(self):
         """Returns an HTML fragment that displays the 'powered by zope'
         button along with a link to the Zope site."""
@@ -195,7 +199,7 @@ class Application(Globals.ApplicationDefaultPermissions,
         # We're at the base of the path.
         return ('',)
 
-    fixupZClassDependencies__roles__=()
+    security.declarePrivate('fixupZClassDependencies')
     def fixupZClassDependencies(self, rebuild=0):
         # Note that callers should not catch exceptions from this method
         # to ensure that the transaction gets aborted if the registry
@@ -232,7 +236,7 @@ class Application(Globals.ApplicationDefaultPermissions,
                             ob._register()
                             result=1
                             if not rebuild:
-                                logger.info('Registered ZClass: %s',ob.id)
+                                LOG.info('Registered ZClass: %s' % ob.id)
                     # Include subobjects.
                     if hasattr(base, 'objectItems'):
                         m = list(ob.objectItems())
@@ -245,13 +249,12 @@ class Application(Globals.ApplicationDefaultPermissions,
                             m = list(ps.methods.objectItems())
                             items.extend(m)
                 except:
-                    logger.warning('Broken objects exist in product %s.',
-                                   product.id,
-                                   exc_info=True)
+                    LOG.warn('Broken objects exist in product %s.' % product.id,
+                             exc_info=sys.exc_info())
 
         return result
 
-    checkGlobalRegistry__roles__=()
+    security.declarePrivate('checkGlobalRegistry')
     def checkGlobalRegistry(self):
         """Check the global (zclass) registry for problems, which can
         be caused by things like disk-based products being deleted.
@@ -259,27 +262,29 @@ class Application(Globals.ApplicationDefaultPermissions,
         try:
             keys=list(self._p_jar.root()['ZGlobals'].keys())
         except:
-            logger.error(
+            LOG.error(
                 'A problem was found when checking the global product '\
                 'registry.  This is probably due to a Product being '\
                 'uninstalled or renamed.  The traceback follows.',
-                exc_info=True)
+                exc_info=sys.exc_info())
             return 1
         return 0
 
-    _setInitializerRegistry__roles__ = ()
+    security.declarePrivate('_setInitializerFlag')
     def _setInitializerFlag(self, flag):
         if self._initializer_registry is None:
             self._initializer_registry = {}
         self._initializer_registry[flag] = 1
 
-    _getInitializerRegistry__roles__ = ()
+    security.declarePrivate('_getInitializerFlag')
     def _getInitializerFlag(self, flag):
         reg = self._initializer_registry
         if reg is None:
             reg = {}
         return reg.get(flag)
 
+InitializeClass(Application)
+
 
 class Expired(Globals.Persistent):
 
@@ -365,7 +370,7 @@ class AppInitializer:
             # tf is a MountPoint object.  This means that the temp_folder
             # couldn't be mounted properly (the meta_type would have been
             # the meta type of the container class otherwise).  The
-            # MountPoint object writes a message to the log so we don't
+            # MountPoint object writes a message to zLOG so we don't
             # need to.
             return
 
@@ -378,11 +383,9 @@ class AppInitializer:
                 mount_paths = [ x[0] for x in dbtab_config.listMountPaths() ]
                 if not '/temp_folder' in mount_paths:
                     # we won't be able to create the mount point properly
-                    logger.error((
-                        'Zope Default Object Creation: '
-                        'Could not initialze a Temporary Folder because '
-                        'a database was not configured to be mounted at '
-                        'the /temp_folder mount point'))
+                    LOG.error('Could not initialze a Temporary Folder because '
+                              'a database was not configured to be mounted at '
+                              'the /temp_folder mount point')
                     return
                 try:
                     manage_addMounts(app, ('/temp_folder',))
@@ -390,11 +393,8 @@ class AppInitializer:
                     self.commit('Added temp_folder')
                     tf = app.temp_folder
                 except:
-                    logger.error((
-                        'Zope Default Object Creation: '
-                        'Could not add a /temp_folder mount point due to an '
-                        'error.'),
-                        exc_info=True)
+                    LOG.error('Could not add a /temp_folder mount point due to an '
+                              'error.', exc_info=sys.exc_info())
                     return
 
         # Ensure that there is a transient object container in the temp folder
@@ -417,15 +417,13 @@ class AppInitializer:
                                   default_period_secs)
 
             if addnotify and app.unrestrictedTraverse(addnotify, None) is None:
-                logger.warning(('Zope Default Object Creation: '
-                                'failed to use nonexistent "%s" script as '
-                                'session-add-notify-script-path'),addnotify)
+                LOG.warn('failed to use nonexistent "%s" script as '
+                         'session-add-notify-script-path' % addnotify)
                 addnotify=None
 
             if delnotify and app.unrestrictedTraverse(delnotify, None) is None:
-                logger.warning(('Zope Default Object Creation: '
-                                'failed to use nonexistent "%s" script as '
-                                'session-delete-notify-script-path'),delnotify)
+                LOG.warn('failed to use nonexistent "%s" script as '
+                         'session-delete-notify-script-path' % delnotify)
                 delnotify=None
 
             if 1:  # Preserve indentation for diff
@@ -561,16 +559,18 @@ class AppInitializer:
         bad_things=0
         try:
             if app.checkGlobalRegistry():
-                logger.info('Beginning attempt to rebuild the global ZClass registry.')
+                LOG.info(
+                    'Beginning attempt to rebuild the global ZClass registry.')
                 app.fixupZClassDependencies(rebuild=1)
                 did_fixups=1
-                logger.info('The global ZClass registry has successfully been rebuilt.')
+                LOG.info(
+                    'The global ZClass registry has successfully been rebuilt.')
                 transaction.get().note('Rebuilt global product registry')
                 transaction.commit()
         except:
             bad_things=1
-            logger.info('The attempt to rebuild the registry failed.',
-                        exc_info=True)
+            LOG.error('The attempt to rebuild the registry failed.',
+                error=sys.exc_info())
             transaction.abort()
 
         # Now we need to see if any (disk-based) products were installed
@@ -586,17 +586,15 @@ class AppInitializer:
             # product was added or updated and we are not a ZEO client.
             if getattr(Globals, '__disk_product_installed__', None):
                 try:
-                    logger.info(
-                        ('New disk product detected, determining if we need '
-                         'to fix up any ZClasses.'))
+                    LOG.info('New disk product detected, determining if we need '
+                             'to fix up any ZClasses.')
                     if app.fixupZClassDependencies():
-                        logger.info('Repaired broken ZClass dependencies.')
+                        LOG.info('Repaired broken ZClass dependencies.')
                         self.commit('Repaired broked ZClass dependencies')
                 except:
-                    logger.error(
-                        ('Attempt to fixup ZClass dependencies after '
-                         'detecting an updated disk-based product failed.'),
-                        exc_info=True)
+                    LOG.error('Attempt to fixup ZClass dependencies after '
+                              'detecting an updated disk-based product failed.',
+                              exc_info=sys.exc_info())
                     transaction.abort()
 
     def install_products(self):
@@ -636,7 +634,7 @@ def install_products(app):
                         folder_permissions, raise_exc=debug_mode)
 
     Products.meta_types=Products.meta_types+tuple(meta_types)
-    Globals.default__class_init__(Folder.Folder)
+    InitializeClass(Folder.Folder)
 
 def get_products():
     """ Return a list of tuples in the form:
@@ -673,13 +671,10 @@ def import_products():
 
     for priority, product_name, index, product_dir in products:
         if done.has_key(product_name):
-            logger.warning(('OFS.Application: '
-                            'Duplicate Product name:'
-                            'After loading Product %s from %s,\n'
-                            'I skipped the one in %s.\n'),
-                           `product_name`,
-                           `done[product_name]`,
-                           `product_dir`)
+            LOG.warn('Duplicate Product name: '
+                     'After loading Product %s from %s, '
+                     'I skipped the one in %s.' % (
+                    `product_name`, `done[product_name]`, `product_dir`) )
             continue
         done[product_name]=product_dir
         import_product(product_dir, product_name, raise_exc=debug_mode)
@@ -712,15 +707,17 @@ def import_product(product_dir, product_name, raise_exc=0, log_exc=1):
                         if type(v) is _st and have_module(v): v=modules[v]
                         modules[k]=v
         except:
+            exc = sys.exc_info()
             if log_exc:
-                logger.error('Could not import %s',pname,exc_info=True)
+                LOG.error('Could not import %s' % pname,
+                          exc_info=exc)
             f=StringIO()
             traceback.print_exc(100,f)
             f=f.getvalue()
             try: modules[pname].__import_error__=f
             except: pass
             if raise_exc:
-                raise sys.exc_info()
+                raise exc[0], exc[1], exc[2]
     finally:
         exc = None
 
@@ -858,8 +855,8 @@ def install_product(app, product_dir, product_name, meta_types,
 
         except:
             if log_exc:
-                logger.error("Couldn't install %s",product_name,
-                             exc_info=True)
+                LOG.error('Couldn\'t install %s' % product_name,
+                           exc_info=sys.exc_info())
             transaction.abort()
             if raise_exc:
                 raise
@@ -889,6 +886,11 @@ def install_standards(app):
                 continue
             app.manage_addProduct['PageTemplates'].manage_addPageTemplate(
                 id=fn, title='', text=open(ob.filename))
+        elif ext in ('.ico', '.gif', '.png'):
+            if hasattr(app, fn):
+                continue
+            app.manage_addProduct['OFSP'].manage_addImage(
+                id=fn, title='', file=open(os.path.join(std_dir, fn)))
         else:
             continue
         wrote = 1
@@ -917,7 +919,7 @@ def reinstall_product(app, product_name):
             break
 
     Products.meta_types=Products.meta_types+tuple(meta_types)
-    Globals.default__class_init__(Folder.Folder)
+    InitializeClass(Folder.Folder)
 
 
 def reimport_product(product_name):
