@@ -10,14 +10,13 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
-__doc__='''Package wrapper for Page Templates
+"""Package wrapper for Page Templates
 
 This wrapper allows the Page Template modules to be segregated in a
 separate package.
 
-$Id: __init__.py 40222 2005-11-18 15:46:28Z andreasjung $'''
-__version__='$$'[11:-2]
-
+$Id: __init__.py 68333 2006-05-29 10:34:19Z philikon $
+"""
 
 # Placeholder for Zope Product data
 misc_ = {}
