@@ -1,4 +1,7 @@
-import os, sys, unittest
+import unittest
+
+import zope.component.testing
+from zope.traversing.adapters import DefaultTraversable
 
 from Products.PageTemplates import Expressions
 from Products.PageTemplates.DeferExpr import LazyWrapper
@@ -9,9 +12,12 @@ class Dummy:
     def __call__(self):
         return 'dummy'
 
-class ExpressionTests(unittest.TestCase):
+class ExpressionTests(zope.component.testing.PlacelessSetup, unittest.TestCase):
 
     def setUp(self):
+        super(ExpressionTests, self).setUp()
+        zope.component.provideAdapter(DefaultTraversable, (None,))
+
         self.e = e = Expressions.getEngine()
         self.ec = e.getContext(
             one = 1,
@@ -20,9 +26,6 @@ class ExpressionTests(unittest.TestCase):
             dummy = Dummy()
             )
 
-    def tearDown(self):
-        del self.e, self.ec
-
     def testCompile(self):
         '''Test expression compilation'''
         e = self.e
@@ -50,9 +53,11 @@ class ExpressionTests(unittest.TestCase):
         '''Test advanced expression evaluation 1'''
         ec = self.ec
         assert ec.evaluate('x | nothing') is None
-        assert ec.evaluate('d/') == 'blank'
+        # empty path elements aren't supported anymore, for the lack
+        # of a use case
+        #assert ec.evaluate('d/') == 'blank'
         assert ec.evaluate('d/_') == 'under'
-        assert ec.evaluate('d/ | nothing') == 'blank'
+        #assert ec.evaluate('d/ | nothing') == 'blank'
         assert ec.evaluate('d/?blank') == 'blank'
 
     def testHybrid(self):
@@ -63,7 +68,15 @@ class ExpressionTests(unittest.TestCase):
         assert ec.evaluate('x | string:x') == 'x'
         assert ec.evaluate('x | string:$one') == '1'
         assert ec.evaluate('x | not:exists:x')
-        
+
+    def testIteratorZRPythonExpr(self):
+        '''Test access to iterator functions from Python expressions'''
+        ec = self.ec
+        ec.beginScope()
+        ec.setRepeat('loop', "python:[1,2,3]")
+        assert ec.evaluate("python:repeat['loop'].odd()")
+        ec.endScope()
+
     def testWrappers(self):
         """Test if defer and lazy are returning their wrappers
         """
@@ -73,6 +86,15 @@ class ExpressionTests(unittest.TestCase):
         self.failUnless(isinstance(defer, DeferWrapper))
         self.failUnless(isinstance(lazy, LazyWrapper))
 
+    def test_empty_ZopePathExpr(self):
+        """Test empty path expressions.
+        """
+        ec = self.ec
+        self.assertEquals(ec.evaluate('path:'), None)
+        self.assertEquals(ec.evaluate('path:  '), None)
+        self.assertEquals(ec.evaluate(''), None)
+        self.assertEquals(ec.evaluate('  \n'), None)
+
 def test_suite():
     return unittest.makeSuite(ExpressionTests)
 
