@@ -13,18 +13,20 @@
 
 __version__='$Revision: 1.96 $'[11:-2]
 
-import re, sys, os, time, random, codecs
+import re, sys, os, time, random, codecs, inspect
 from types import StringType, UnicodeType
-from BaseRequest import BaseRequest, quote
+from BaseRequest import BaseRequest
 from HTTPResponse import HTTPResponse
 from cgi import FieldStorage, escape
-from urllib import unquote, splittype, splitport
+from urllib import quote, unquote, splittype, splitport
 from copy import deepcopy
 from Converters import get_converter
 from TaintedString import TaintedString
 from maybe_lock import allocate_lock
 xmlrpc=None # Placeholder for module that we'll import if we have to.
 
+from zope.publisher.base import DebugFlags
+
 # This may get overwritten during configuration
 default_encoding = 'iso-8859-15'
 
@@ -262,6 +264,7 @@ class HTTPRequest(BaseRequest):
         self.steps=[]
         self._steps=[]
         self._lazies={}
+        self._debug = DebugFlags()
 
 
         if environ.has_key('REMOTE_ADDR'):
@@ -269,15 +272,7 @@ class HTTPRequest(BaseRequest):
             if environ.has_key('HTTP_X_FORWARDED_FOR') and self._client_addr in trusted_proxies:
                 # REMOTE_ADDR is one of our trusted local proxies. Not really very remote at all.
                 # The proxy can tell us the IP of the real remote client in the forwarded-for header
-                # Skip the proxy-address itself though
-                forwarded_for = [
-                    e.strip()
-                    for e in environ['HTTP_X_FORWARDED_FOR'].split(',')]
-                forwarded_for.reverse()
-                for entry in forwarded_for:
-                    if entry not in trusted_proxies:
-                        self._client_addr = entry
-                        break
+                self._client_addr = environ['HTTP_X_FORWARDED_FOR'].split(',')[-1].strip()
         else:
             self._client_addr = ''
 
@@ -1221,7 +1216,18 @@ class HTTPRequest(BaseRequest):
             raise KeyError, key
         return v
 
+    # Using the getattr protocol to retrieve form values and similar
+    # is discouraged and is likely to be deprecated in the future.
+    # request.get(key) or request[key] should be used instead
     def __getattr__(self, key, default=_marker, returnTaints=0):
+        # ugly hack to make request.debug work for Zope 3 code (the
+        # ZPT engine, to be exact) while retaining request.debug
+        # functionality for all other code
+        if key == 'debug':
+            lastframe = inspect.currentframe().f_back
+            if lastframe.f_globals['__name__'].startswith('zope.'):
+                return self._debug
+        
         v = self.get(key, default, returnTaints=returnTaints)
         if v is _marker:
             raise AttributeError, key
@@ -1457,7 +1463,7 @@ def parse_cookie(text,
                  qparmre=re.compile(
                     '([\x00- ]*([^\x00- ;,="]+)="([^"]*)"([\x00- ]*[;,])?[\x00- ]*)'),
                  parmre=re.compile(
-                    '([\x00- ]*([^\x00- ;,="]+)=([^;,"]*)([\x00- ]*[;,])?[\x00- ]*)'),
+                    '([\x00- ]*([^\x00- ;,="]+)=([^\x00- ;,"]*)([\x00- ]*[;,])?[\x00- ]*)'),
                  paramlessre=re.compile(
                     '([\x00- ]*([^\x00- ;,="]+)[\x00- ]*[;,][\x00- ]*)'),
 
@@ -1492,11 +1498,11 @@ def parse_cookie(text,
 
             else:
                 # Broken Cookie without = nor value.
- 		broken_p = paramlessre.match(text)
- 		if broken_p:
- 		    l = len(broken_p.group(1))
- 		    name = broken_p.group(2)
- 		    value = ''
+                broken_p = paramlessre.match(text)
+                if broken_p:
+                    l = len(broken_p.group(1))
+                    name = broken_p.group(2)
+                    value = ''
 
                 else:
                     return result
