@@ -13,17 +13,17 @@
 ##############################################################################
 """Browser Widget Definitions
 
-$Id: widget.py 73027 2007-03-07 11:56:45Z zagy $
+$Id: widget.py 67630 2006-04-27 00:54:03Z jim $
 """
 __docformat__ = 'restructuredtext'
 
 from xml.sax.saxutils import quoteattr, escape
 
+from zope.component import getMultiAdapter
 from zope.interface import implements
 from zope.schema.interfaces import ValidationError
-from zope.app.publisher.browser import BrowserView
+from zope.publisher.browser import BrowserView
 
-from zope.app import zapi
 from zope.app.form import Widget, InputWidget
 from zope.app.form.interfaces import ConversionError
 from zope.app.form.interfaces import InputErrors
@@ -34,15 +34,6 @@ from zope.app.form.browser.interfaces import IWidgetInputErrorView
 
 import warnings
 
-
-if quoteattr("\r") != '"&13;"':
-    _quoteattr = quoteattr
-
-    def quoteattr(data):
-        return _quoteattr(
-            data, {'\n': '&#10;', '\r': '&#13;', '\t':'&#9;'})
-
-
 class BrowserWidget(Widget, BrowserView):
     """Base class for browser widgets.
 
@@ -110,8 +101,8 @@ class BrowserWidget(Widget, BrowserView):
 
     def error(self):
         if self._error:
-            return zapi.getMultiAdapter((self._error, self.request),
-                                        IWidgetInputErrorView).snippet()
+            return getMultiAdapter((self._error, self.request),
+                                   IWidgetInputErrorView).snippet()
         return ""
 
     def hidden(self):
@@ -175,12 +166,8 @@ class SimpleInputWidget(BrowserWidget, InputWidget):
         >>> widget.error()
         ''
 
-    You can use 'setPrefix' to remove or modify the prefix used to create the
-    widget name as follows:
+    You can modify the prefix used to create the widget name as follows:
 
-        >>> widget.setPrefix('')
-        >>> widget.name
-        'foo'
         >>> widget.setPrefix('baz')
         >>> widget.name
         'baz.foo'
@@ -257,28 +244,19 @@ class SimpleInputWidget(BrowserWidget, InputWidget):
         ...             return float(input)
         ...         except ValueError, v:
         ...             raise ConversionError('Invalid floating point data', v)
-        ...
-        ...     def _toFormValue(self, value):
-        ...         value = super(FloatWidget, self)._toFormValue(value)
-        ...         return '%.2f' % value
 
         >>> request = TestRequest(form={'field.price': u'32.0'})
         >>> widget = FloatWidget(field, request)
         >>> widget.getInputValue()
         32.0
-        >>> widget()
-        u'<input class="textType" id="field.price" name="field.price" type="text" value="32.00"  />'
 
-        >>> request = TestRequest(form={'field.price': u'<p>foo</p>'})
+        >>> request = TestRequest(form={'field.price': u'foo'})
         >>> widget = FloatWidget(field, request)
         >>> try:
         ...     widget.getInputValue()
         ... except ConversionError, error:
         ...     print error.doc()
         Invalid floating point data
-        >>> widget()
-        u'<input class="textType" id="field.price" name="field.price" type="text" value="&lt;p&gt;foo&lt;/p&gt;"  />'
-
 
     >>> tearDown()
     """
@@ -374,54 +352,28 @@ class SimpleInputWidget(BrowserWidget, InputWidget):
         else:
             return value
 
-    def _getCurrentValueHelper(self):
-        """Helper to get the current input value.
-
-        Raises InputErrors if the data could not be validated/converted.
-        """
-        input_value = None
-        if self._renderedValueSet():
-            input_value = self._data
-        else:
+    def _getFormValue(self):
+        """Returns a value suitable for use in an HTML form."""
+        if not self._renderedValueSet():
             if self.hasInput():
+
                 # It's insane to use getInputValue this way. It can
                 # cause _error to get set spuriously.  We'll work
                 # around this by saving and restoring _error if
                 # necessary.
                 error = self._error
                 try:
-                    input_value = self.getInputValue()
+                    try:
+                        value = self.getInputValue()
+                    except InputErrors:
+                        return self.request.form.get(self.name, self._missing)
                 finally:
                     self._error = error
             else:
-                input_value = self._getDefault()
-        return input_value
-
-    def _getCurrentValue(self):
-        """Returns the current input value.
-
-        Returns None if the data could not be validated/converted.
-        """
-        try:
-            input_value = self._getCurrentValueHelper()
-        except InputErrors:
-            input_value = None
-        return input_value
-
-    def _getFormValue(self):
-        """Returns a value suitable for use in an HTML form.
-
-        Detects the status of the widget and selects either the input value
-        that came from the request, the value from the _data attribute or the
-        default value.
-        """
-        try:
-            input_value = self._getCurrentValueHelper()
-        except InputErrors:
-            form_value = self.request.form.get(self.name, self._missing)
+                value = self._getDefault()
         else:
-            form_value = self._toFormValue(input_value)
-        return form_value
+            value = self._data
+        return self._toFormValue(value)
 
     def _getDefault(self):
         """Returns the default value for this widget."""
