@@ -10,11 +10,10 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""
+"""Forms
 
-$Id: form.py 71640 2006-12-21 00:07:40Z jacobholm $
+$Id: form.py 69417 2006-08-12 10:33:10Z philikon $
 """
-
 import datetime
 import re
 import sys
@@ -22,43 +21,35 @@ import pytz
 
 import zope.event
 import zope.i18n
+import zope.i18nmessageid
+import zope.security
+import zope.interface.interfaces
+import zope.publisher.browser
 import zope.publisher.interfaces.browser
-
 from zope import component, interface, schema
-
 from zope.interface.common import idatetime
 from zope.interface.interface import InterfaceClass
-import zope.interface.interfaces
 from zope.schema.interfaces import IField
 from zope.schema.interfaces import ValidationError
 import zope.security
+from zope.lifecycleevent import ObjectCreatedEvent, ObjectModifiedEvent
 
 import zope.app.container.interfaces
-import zope.app.event.objectevent
 import zope.app.form.browser.interfaces
 from zope.app.form.interfaces import IInputWidget, IDisplayWidget
 from zope.app.form.interfaces import WidgetsError, MissingInputError
 from zope.app.form.interfaces import InputErrors, WidgetInputError
 from zope.app.pagetemplate import ViewPageTemplateFile
-from zope.app.publisher.browser import BrowserView
 
-import zope.formlib.page
 from zope.formlib import interfaces, namedtemplate
-from zope.formlib.i18n import _
+from zope.i18nmessageid import MessageFactory
+_ = MessageFactory("zope")
+
 
 interface.moduleProvides(interfaces.IFormAPI)
 
 _identifier = re.compile('[A-Za-z][a-zA-Z0-9_]*$')
 
-def expandPrefix(prefix):
-    """Expand prefix string by adding a trailing period if needed.
-
-    expandPrefix(p) should be used instead of p+'.' in most contexts.
-    """
-    if prefix and not prefix.endswith('.'):
-        return prefix + '.'
-    return prefix
-
 class FormField:
 
     interface.implements(interfaces.IFormField)
@@ -71,7 +62,9 @@ class FormField:
         if name is None:
             name = field.__name__
         assert name
-        self.__name__ = expandPrefix(prefix) + name
+        if prefix:
+            name = prefix + '.' + name
+        self.__name__ = name
         self.prefix = prefix
         self.for_display = for_display
         self.for_input = for_input
@@ -173,23 +166,12 @@ class Widgets(object):
 
     interface.implements(interfaces.IWidgets)
 
-    def __init__(self, widgets, prefix_length=None, prefix=None):
+    def __init__(self, widgets, prefix_length):
         self.__Widgets_widgets_items__ = widgets
         self.__Widgets_widgets_list__ = [w for (i, w) in widgets]
-        if prefix is None:
-            # BBB Allow old code using the prefix_length argument.
-            if prefix_length is None:
-                raise TypeError(
-                    "One of 'prefix_length' and 'prefix' is required."
-                    )
-            self.__Widgets_widgets_dict__ = dict(
-                [(w.name[prefix_length:], w) for (i, w) in widgets]
-                )
-        else:
-            prefix = expandPrefix(prefix)
-            self.__Widgets_widgets_dict__ = dict(
-                [(_widgetKey(w, prefix), w) for (i, w) in widgets]
-                )
+        self.__Widgets_widgets_dict__ = dict(
+            [(w.name[prefix_length:], w) for (i, w) in widgets]
+            )
 
     def __iter__(self):
         return iter(self.__Widgets_widgets_list__)
@@ -275,7 +257,7 @@ def setUpWidgets(form_fields,
 
         prefix = form_prefix
         if form_field.prefix:
-            prefix = expandPrefix(prefix) + form_field.prefix
+            prefix += '.' + form_field.prefix
 
         widget.setPrefix(prefix)
 
@@ -292,7 +274,7 @@ def setUpWidgets(form_fields,
 
         widgets.append((not readonly, widget))
 
-    return Widgets(widgets, prefix=form_prefix)
+    return Widgets(widgets, len(form_prefix)+1)
 
 def setUpInputWidgets(form_fields, form_prefix, context, request,
                       form=None, ignore_request=False):
@@ -303,7 +285,7 @@ def setUpInputWidgets(form_fields, form_prefix, context, request,
 
         prefix = form_prefix
         if form_field.prefix:
-            prefix = expandPrefix(prefix) + form_field.prefix
+            prefix += '.' + form_field.prefix
 
         widget.setPrefix(prefix)
 
@@ -315,7 +297,7 @@ def setUpInputWidgets(form_fields, form_prefix, context, request,
             widget.setRenderedValue(value)
 
         widgets.append((True, widget))
-    return Widgets(widgets, prefix=form_prefix)
+    return Widgets(widgets, len(form_prefix)+1)
 
 
 def _createWidget(form_field, field, request, iface):
@@ -327,14 +309,14 @@ def _createWidget(form_field, field, request, iface):
 
 def getWidgetsData(widgets, form_prefix, data):
     errors = []
-    form_prefix = expandPrefix(form_prefix)
+    form_prefix += '.'
 
     for input, widget in widgets.__iter_input_and_widget__():
         if input and IInputWidget.providedBy(widget):
             name = _widgetKey(widget, form_prefix)
 
             if not widget.hasInput():
-                continue
+                raise interfaces.FormError("No input", name)
 
             try:
                 data[name] = widget.getInputValue()
@@ -394,7 +376,7 @@ def setUpEditWidgets(form_fields, form_prefix, context, request,
 
         prefix = form_prefix
         if form_field.prefix:
-            prefix = expandPrefix(prefix) + form_field.prefix
+            prefix += '.' + form_field.prefix
 
         widget.setPrefix(prefix)
 
@@ -405,7 +387,7 @@ def setUpEditWidgets(form_fields, form_prefix, context, request,
 
         widgets.append((not readonly, widget))
 
-    return Widgets(widgets, prefix=form_prefix)
+    return Widgets(widgets, len(form_prefix)+1)
 
 def setUpDataWidgets(form_fields, form_prefix, context, request, data=(),
                      for_display=False, ignore_request=False):
@@ -421,8 +403,7 @@ def setUpDataWidgets(form_fields, form_prefix, context, request, data=(),
 
         prefix = form_prefix
         if form_field.prefix:
-            prefix = expandPrefix(prefix) + form_field.prefix
-
+            prefix += '.' + form_field.prefix
         widget.setPrefix(prefix)
 
         if ((form_field.__name__ in data)
@@ -432,7 +413,7 @@ def setUpDataWidgets(form_fields, form_prefix, context, request, data=(),
 
         widgets.append((not readonly, widget))
 
-    return Widgets(widgets, prefix=form_prefix)
+    return Widgets(widgets, len(form_prefix)+1)
 
 
 class NoInputData(interface.Invalid):
@@ -565,7 +546,7 @@ class Action(object):
             else:
                 name = label.encode('hex')
 
-        self.__name__ = expandPrefix(prefix) + name
+        self.__name__ = prefix + '.' + name
 
         if data is None:
             data = {}
@@ -577,7 +558,7 @@ class Action(object):
         result = self.__class__.__new__(self.__class__)
         result.__dict__.update(self.__dict__)
         result.form = form
-        result.__name__ = expandPrefix(form.prefix) + result.__name__
+        result.__name__ = form.prefix + '.' + result.__name__
         interface.alsoProvides(result, interfaces.IBoundAction)
         return result
 
@@ -585,6 +566,13 @@ class Action(object):
         condition = self.condition
         return (condition is None) or condition(self.form, self)
 
+    def submitted(self):
+        if not self.available():
+            return False
+        form = self.form
+        name = "%s.%s" % (form.prefix, self.__name__)
+        return name in form.request.form
+
     def validate(self, data):
         if self.validator is not None:
             return self.validator(self.form, self, data)
@@ -610,7 +598,7 @@ def render_submit_button(self):
     if not self.available():
         return ''
     label = self.label
-    if isinstance(label, (zope.i18n.Message, zope.i18n.MessageID)):
+    if isinstance(label, zope.i18nmessageid.Message):
         label = zope.i18n.translate(self.label, context=self.form.request)
     return ('<input type="submit" id="%s" name="%s" value="%s"'
             ' class="button" />' %
@@ -691,7 +679,7 @@ def availableActions(form, actions):
     return result
 
 
-class FormBase(zope.formlib.page.Page):
+class FormBase(zope.publisher.browser.BrowserPage):
 
     label = u''
 
@@ -734,13 +722,7 @@ class FormBase(zope.formlib.page.Page):
 
         data = {}
         errors, action = handleSubmit(self.actions, data, self.validate)
-        # the following part will make sure that previous error not
-        # get overriden by new errors. This is usefull for subforms. (ri)
-        if self.errors is None:
-            self.errors = errors
-        else:
-            if errors is not None:
-                self.errors += tuple(errors)
+        self.errors = errors
 
         if errors:
             self.status = _('There were errors')
@@ -785,7 +767,6 @@ class FormBase(zope.formlib.page.Page):
                 else:
                     yield view.snippet()
 
-
 def haveInputWidgets(form, action):
     for input, widget in form.widgets.__iter_input_and_widget__():
         if input:
@@ -805,8 +786,7 @@ class EditFormBase(FormBase):
     @action(_("Apply"), condition=haveInputWidgets)
     def handle_edit_action(self, action, data):
         if applyChanges(self.context, self.form_fields, data, self.adapters):
-            zope.event.notify(
-                zope.app.event.objectevent.ObjectModifiedEvent(self.context))
+            zope.event.notify(ObjectModifiedEvent(self.context))
             formatter = self.request.locale.dates.getFormatter(
                 'dateTime', 'medium')
 
@@ -865,8 +845,7 @@ class AddFormBase(FormBase):
 
     def createAndAdd(self, data):
         ob = self.create(data)
-        zope.event.notify(
-            zope.app.event.objectevent.ObjectCreatedEvent(ob))
+        zope.event.notify(ObjectCreatedEvent(ob))
         return self.add(ob)
 
     def create(self, data):
