@@ -13,7 +13,7 @@
 ##############################################################################
 """HTTP Publisher
 
-$Id: http.py 70593 2006-10-09 19:16:43Z mgedmin $
+$Id: http.py 69340 2006-08-02 14:16:04Z mj $
 """
 import re, time, random
 from cStringIO import StringIO
@@ -25,8 +25,7 @@ from Cookie import CookieError
 import logging
 from tempfile import TemporaryFile
 
-from zope import component, interface
-
+from zope import component, interface, event
 from zope.deprecation import deprecation
 
 from zope.publisher import contenttype
@@ -34,6 +33,7 @@ from zope.publisher.interfaces.http import IHTTPCredentials
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.publisher.interfaces.http import IHTTPApplicationRequest
 from zope.publisher.interfaces.http import IHTTPPublisher
+from zope.publisher.interfaces.http import IHTTPVirtualHostChangedEvent
 
 from zope.publisher.interfaces import Redirect
 from zope.publisher.interfaces.http import IHTTPResponse
@@ -58,8 +58,6 @@ class CookieMapper(RequestDataMapper):
 class HeaderGetter(RequestDataGetter):
     _gettrname = 'getHeader'
 
-base64 = None
-
 def sane_environment(env):
     # return an environment mapping which has been cleaned of
     # funny business such as REDIRECT_ prefixes added by Apache
@@ -76,6 +74,14 @@ def sane_environment(env):
         dict['PATH_INFO'] = dict['PATH_INFO'].decode('utf-8')
     return dict
 
+class HTTPVirtualHostChangedEvent(object):
+    interface.implements(IHTTPVirtualHostChangedEvent)
+    
+    request = None
+    
+    def __init__(self, request):
+        self.request = request
+
 # Possible HTTP status responses
 status_reasons = {
 100: 'Continue',
@@ -198,11 +204,7 @@ class HTTPInputStream(object):
         self.cacheStream.write(data)
         return data
 
-    def readline(self, size=None):
-        # XXX We should pass the ``size`` argument to self.stream.readline
-        # but twisted.web2.wsgi.InputStream.readline() doesn't accept it.
-        # See http://www.zope.org/Collectors/Zope3-dev/535 and
-        #     http://twistedmatrix.com/trac/ticket/1451
+    def readline(self):
         data = self.stream.readline()
         self.cacheStream.write(data)
         return data
@@ -449,10 +451,10 @@ class HTTPRequest(BaseRequest):
         request._retry_count = self._retry_count
         return request
 
-    def traverse(self, object):
+    def traverse(self, obj):
         'See IPublisherRequest'
 
-        ob = super(HTTPRequest, self).traverse(object)
+        ob = super(HTTPRequest, self).traverse(obj)
         if self._path_suffix:
             self._traversal_stack = self._path_suffix
             ob = super(HTTPRequest, self).traverse(ob)
@@ -487,14 +489,10 @@ class HTTPRequest(BaseRequest):
 
     def _authUserPW(self):
         'See IHTTPCredentials'
-        global base64
-        if self._auth:
-            if self._auth.lower().startswith('basic '):
-                if base64 is None:
-                    import base64
-                name, password = base64.decodestring(
-                    self._auth.split()[-1]).split(':')
-                return name, password
+        if self._auth and self._auth.lower().startswith('basic '):
+            encoded = self._auth.split(None, 1)[-1]
+            name, password = encoded.decode("base64").split(':', 1)
+            return name, password
 
     def unauthorized(self, challenge):
         'See IHTTPCredentials'
@@ -557,6 +555,7 @@ class HTTPRequest(BaseRequest):
         if port and str(port) != DEFAULT_PORTS.get(proto):
             host = '%s:%s' % (host, port)
         self._app_server = '%s://%s' % (proto, host)
+        event.notify(HTTPVirtualHostChangedEvent(self))
 
     def shiftNameToApplication(self):
         """Add the name being traversed to the application name
@@ -567,6 +566,7 @@ class HTTPRequest(BaseRequest):
         """
         if len(self._traversed_names) == 1:
             self._app_names.append(self._traversed_names.pop())
+            event.notify(HTTPVirtualHostChangedEvent(self))
             return
 
         raise ValueError("Can only shift leading traversal "
@@ -576,6 +576,7 @@ class HTTPRequest(BaseRequest):
         del self._traversed_names[:]
         self._vh_root = self._last_obj_traversed
         self._app_names = list(names)
+        event.notify(HTTPVirtualHostChangedEvent(self))
 
     def getVirtualHostRoot(self):
         return self._vh_root
@@ -978,6 +979,7 @@ def sort_charsets(x, y):
 
 
 class HTTPCharsets(object):
+    component.adapts(IHTTPRequest)
     interface.implements(IUserPreferredCharsets)
 
     def __init__(self, request):
